# Syns - Deutsche Synonyme auf der Kommandozeile
Dieses Python Modul stellt eine einfache cli-Schnittstelle zur API von
openthesaurus.de dar.

Mehr Informationen: https://www.openthesaurus.de/about/api
